@@ -28,7 +28,7 @@ class KComboBox;
   */
 
 class KnowitChooser : public KDialogBase  {
-   Q_OBJECT
+   TQ_OBJECT
   
 protected:
    KComboBox* notes;
