@@ -25,7 +25,7 @@ class TQDragEnterEvent;
 
 class KnowitLinks : public TDEListBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KnowitLinks(TQWidget* parent=0, const char* name = 0);
